@@ -21,12 +21,7 @@
  * Copyright 2008 Novell, Inc.
  */
 
-#ifdef HAVE_CONFIG_H
-#include <config.h>
-#endif
-
-#include <glib/gi18n.h>
-#include <gtk/gtk.h>
+#include "nm-default.h"
 
 #include "applet.h"
 #include "applet-device-ethernet.h"
