@@ -20,7 +20,7 @@
  * Copyright 2008 - 2014 Red Hat, Inc.
  */
 
-#include "config.h"
+#include "nm-default.h"
 
 #include <netinet/in.h>
 #include <sys/socket.h>
@@ -28,9 +28,6 @@
 
 #include <NetworkManager.h>
 
-#include <gtk/gtk.h>
-#include <glib/gi18n.h>
-
 #include "applet-dialogs.h"
 #include "utils.h"
 
