@@ -20,7 +20,7 @@
  * Copyright 2008 - 2014 Red Hat, Inc.
  */
 
-#include "config.h"
+#include "nm-default.h"
 
 #include <netinet/in.h>
 #include <sys/types.h>
@@ -30,7 +30,6 @@
 #include <stdlib.h>
 #include <string.h>
 
-#include <glib/gi18n.h>
 #include <gdk/gdkkeysyms.h>
 
 #include "ip4-routes-dialog.h"
