@@ -20,14 +20,11 @@
  * Copyright 2008 - 2014 Red Hat, Inc.
  */
 
-#include "config.h"
+#include "nm-default.h"
 
 #include <string.h>
 #include <net/ethernet.h>
 
-#include <gtk/gtk.h>
-#include <glib/gi18n.h>
-
 #include "page-ethernet.h"
 
 G_DEFINE_TYPE (CEPageEthernet, ce_page_ethernet, CE_TYPE_PAGE)
