@@ -20,14 +20,11 @@
  * Copyright 2008 - 2014 Red Hat, Inc.
  */
 
-#include "config.h"
+#include "nm-default.h"
 
 #include <string.h>
 #include <math.h>
 
-#include <gtk/gtk.h>
-#include <glib/gi18n.h>
-
 #include "nm-connection-editor.h"
 #include "page-wifi.h"
 
