@@ -20,14 +20,10 @@
  * Copyright 2007 - 2014 Red Hat, Inc.
  */
 
-#include "config.h"
+#include "nm-default.h"
 
 #include <string.h>
 
-#include <glib.h>
-#include <gtk/gtk.h>
-#include <glib/gi18n.h>
-
 #include "wireless-security.h"
 #include "eap-method.h"
 #include "utils.h"
