@@ -20,9 +20,9 @@
  * Copyright 2007 - 2014 Red Hat, Inc.
  */
 
+#include "nm-default.h"
+
 #include <string.h>
-#include <glib.h>
-#include <glib/gi18n.h>
 
 #include "wireless-security.h"
 #include "utils.h"
